Welcome to ClientVPS Mirrors

Help for package GreedyExperimentalDesignJARs
Version: 1.0
Title: GreedyExperimentalDesign JARs
Type: Package
Date: 2018-07-15
Author: Adam Kapelner, David Azriel, Abba Krieger see COPYRIGHTS file for the authors of the java libraries
Maintainer: Adam Kapelner <kapelner@qc.cuny.edu>
Description: These are GreedyExperimentalDesign Java dependency libraries. Note: this package has no functionality of its own and should not be installed as a standalone package without GreedyExperimentalDesign.
License: GPL-3
Depends: R (≥ 2.14.0), rJava (≥ 0.9-8)
SystemRequirements: Java (>= 7.0)
NeedsCompilation: no
Packaged: 2018-07-15 08:29:01 UTC; AdamLenovo
Repository: CRAN
Date/Publication: 2018-07-15 14:50:02 UTC

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.